Description Usage Format Details
This dataset is the result of the modifications of all the other datasets in this package into classes for integration into an ontology. format.
1 |
An object of class tbl_df (inherits from tbl, data.frame) with 215271 rows and 2 columns.
See the mcode-rdf vignette for more details.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.